This folder contains [lin.py](lin.py), which generates a Modelica script to
linearize Modelica.Blocks.Continuous.PID from the [Modelica Standard Library]
with various parameter settings and plots the results.  The results of that
script are also generated here.


[Modelica Standard Library]: https://github.com/modelica/ModelicaStandardLibrary
